window.Gleam.initSearch([{"doc":"file_streams","title":"file_streams","content":"# Gleam File Streams\n\nThis Gleam library provides access to Erlang&#39;s file streams for reading and\nwriting files. If you don&#39;t require streaming behavior then consider using\n[`simplifile`](https://hex.pm/packages/simplifile) instead.\n\nThis library only supports the Erlang target.\n\n[![Package Version](https://img.shields.io/hexpm/v/file_streams)](https://hex.pm/packages/file_streams)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/file_streams/)\n\n## Example\n\nAdd this library to your project:\n\n```sh\ngleam add file_streams\n```\n\nThe following code writes data to a file using a binary file stream, reads it\nback in using a binary file stream, then reads it again with a text file stream.\n\n```gleam\nimport file_streams/file_stream\nimport file_streams/file_stream_error\nimport gleam/bit_array\n\n// Write file as a binary stream\nlet assert Ok(stream) = file_stream.open_write(&quot;test.txt&quot;)\nlet assert Ok(Nil) = file_stream.write_bytes(stream, &lt;&lt;&quot;Hello, world!\\n&quot;:utf8&gt;&gt;)\nlet assert Ok(Nil) = file_stream.write_bytes(stream, &lt;&lt;&quot;12&quot;:utf8&gt;&gt;)\nlet assert Ok(Nil) = file_stream.close(stream)\n\n// Read file as a binary stream\nlet assert Ok(stream) = file_stream.open_read(&quot;test.txt&quot;)\nlet assert Ok(bytes) = file_stream.read_bytes(stream, 14)\nlet assert Ok(&quot;Hello, world!\\n&quot;) = bit_array.to_string(bytes)\nlet assert Ok([49, 50]) =\n  file_stream.read_list(stream, file_stream.read_uint8, 2)\nlet assert Error(file_stream_error.Eof) = file_stream.read_bytes(stream, 1)\nlet assert Ok(Nil) = file_stream.close(stream)\n\n// Read file as a UTF-8 text stream\nlet assert Ok(stream) = file_stream.open_read_text(&quot;test.txt&quot;)\nlet assert Ok(&quot;Hello&quot;) = file_stream.read_chars(stream, 5)\nlet assert Ok(&quot;, world!\\n&quot;) = file_stream.read_line(stream)\nlet assert Ok(&quot;12&quot;) = file_stream.read_line(stream)\nlet assert Error(file_stream_error.Eof) = file_stream.read_line(stream)\nlet assert Ok(Nil) = file_stream.close(stream)\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/file_streams/&gt;.\n\n## License\n\nThis library is published under the MIT license, a copy of which is included.\n","url":"index.html"},{"doc":"file_streams/text_encoding","title":"Endianness","content":"pub type Endianness {\n  Big\n  Little\n}\n Endianness specifier used by the `Utf16` and `Utf32` text encodings.\n\nBig\n Big endian. This is much less common than little endian.\n\nLittle\n Little endian. This is much more common than big endian.\n\nSynonyms:\nfile_streams/text_encoding.Endianness\nfile_streams/text_encoding Endianness","url":"file_streams/text_encoding.html#Endianness"},{"doc":"file_streams/text_encoding","title":"TextEncoding","content":"pub type TextEncoding {\n  Unicode\n  Latin1\n  Utf16(endianness: Endianness)\n  Utf32(endianness: Endianness)\n}\n Text encoding for a file stream. The default encoding is `Unicode` (UTF-8).\n\n Text read from a file stream using\n [`file_stream.read_chars()`](./file_stream.html#read_chars) and\n [`file_stream.read_line()`](./file_stream.html#read_line) will be\n automatically converted from the specified encoding to a `String`.\n Similarly, text written to a file stream using\n [`file_stream.write_chars()`](./file_stream.html#write_chars) will be\n converted to the specified encoding before being written to a file stream.\n\nUnicode\n The Unicode UTF-8 text encoding. This is the default encoding.\n\nLatin1\n The ISO 8859-1 (Latin-1) text encoding.\n\n When using this encoding, `file_stream.write_chars()` can only write\n Unicode codepoints up to `U+00FF`.\n\nUtf16(endianness: Endianness)\n The Unicode UTF-16 text encoding, with the specified byte ordering.\n\nUtf32(endianness: Endianness)\n The Unicode UTF-32 text encoding, with the specified byte ordering.\n\nSynonyms:\nfile_streams/text_encoding.TextEncoding\nfile_streams/text_encoding TextEncoding","url":"file_streams/text_encoding.html#TextEncoding"},{"doc":"file_streams/text_encoding","title":"file_streams/text_encoding","content":" The encodings available for reading and writing text with a file stream.","url":"file_streams/text_encoding.html"},{"doc":"file_streams/file_open_mode","title":"FileOpenMode","content":"pub type FileOpenMode {\n  Append\n  Binary\n  DelayedWrite(size: Int, delay: Int)\n  Encoding(encoding: TextEncoding)\n  Exclusive\n  Raw\n  Read\n  ReadAhead(size: Int)\n  Write\n}\n The modes that can be specified when opening a file stream with\n [`file_stream.open()`](./file_stream.html#open).\n\nAppend\n The file is opened for writing. It is created if it does not exist. Every\n write operation to a file opened with `Append` takes place at the end of\n the file.\n\nBinary\n Causes read operations on the file stream to return binaries rather than\n lists.\n \n If this mode is specified then binary data can be read from and/or written\n to the file stream. If it is not specified then text data data can be read\n from and/or written to the file stream.\n\n This mode must not be present when the `Encoding(...)` mode is present.\n\nDelayedWrite(size: Int, delay: Int)\n Data in subsequent `file_stream.write_*` calls are buffered until at least\n `size` bytes are buffered, or until the oldest buffered data is `delay`\n milliseconds old. Then all buffered data is written in one operating\n system call. The buffered data is also flushed before some other file\n operations that are not `file_stream.write_*` calls.\n\n The purpose of this option is to increase performance by reducing the\n number of operating system calls. Thus, `file_stream.write_*` calls must\n be for sizes significantly less than `size`, and should not interspersed\n by too many other file operations.\n\n When this option is used, the result of `file_stream.write_*` calls can\n prematurely be reported as successful, and if a write error occurs, the\n error is reported as the result of the next file operation, which is not\n executed.\n\n For example, when `DelayedWrite` is used, after a number of\n `file_stream.write_*` calls,\n [`file_stream.close()`](./file_stream.html#close) can return\n `Error(FileStreamError(Enospc)))` as there is not enough space on the\n device for previously written data.\n [`file_stream.close()`](./file_stream.html#close) must be called again, as\n the file is still open.\n\nEncoding(encoding: TextEncoding)\n Makes the file stream perform automatic translation of text to and from\n the specified text encoding when using the \n [`file_stream.read_line()`](./file_stream.html#read_line),\n [`file_stream.read_chars()`](./file_stream.html#read_chars), and\n [`file_stream.write_chars()`](./file_stream.html#write_chars) functions.\n\n If characters are written that can&#39;t be converted to the specified\n encoding then an error occurs and the file is closed.\n\nExclusive\n The file is opened for writing. It is created if it does not exist. If the\n file exists, `Error(FileStreamError(Eexist))` is returned by\n [`file_stream.open()`](./file_stream.html#open).\n\n This option does not guarantee exclusiveness on file systems not\n supporting `O_EXCL` properly, such as NFS. Do not depend on this option\n unless you know that the file system supports it (in general, local file\n systems are safe).\n\nRaw\n Allows faster access to a file, as no Erlang process is needed to handle\n the file. However, a file opened in this way has the following\n limitations:\n \n - Only the Erlang process that opened the file can use it.\n - Text-based reading and writing can&#39;t be performed, as it depends on the\n   `io` module which cannot be used in raw mode, as it can only talk to an\n   Erlang process.\n - A remote Erlang file server cannot be used. The computer on which the\n   Erlang node is running must have access to the file system (directly or\n   through NFS).\n\nRead\n The file, which must exist, is opened for reading.\n\nReadAhead(size: Int)\n Activates read data buffering. If `file_stream.read_*` calls are for\n significantly less than `size` bytes, read operations to the operating\n system are still performed for blocks of `size` bytes. The extra data is\n buffered and returned in subsequent `file_stream.read_*` calls, giving a\n performance gain as the number of operating system calls is reduced.\n\n If `file_stream.read_*` calls are for sizes not significantly less than\n `size` bytes, or are greater than `size` bytes, no performance gain can be\n expected.\n\nWrite\n The file is opened for writing. It is created if it does not exist. If the\n file exists and `Write` is not combined with `Read`, the file is\n truncated.\n\nSynonyms:\nfile_streams/file_open_mode.FileOpenMode\nfile_streams/file_open_mode FileOpenMode","url":"file_streams/file_open_mode.html#FileOpenMode"},{"doc":"file_streams/file_open_mode","title":"file_streams/file_open_mode","content":"","url":"file_streams/file_open_mode.html"},{"doc":"file_streams/file_stream_error","title":"FileStreamError","content":"pub type FileStreamError {\n  Eacces\n  Eagain\n  Ebadf\n  Ebadmsg\n  Ebusy\n  Edeadlk\n  Edeadlock\n  Edquot\n  Eexist\n  Efault\n  Efbig\n  Eftype\n  Eintr\n  Einval\n  Eio\n  Eisdir\n  Eloop\n  Emfile\n  Emlink\n  Emultihop\n  Enametoolong\n  Enfile\n  Enobufs\n  Enodev\n  Enolck\n  Enolink\n  Enoent\n  Enomem\n  Enospc\n  Enosr\n  Enostr\n  Enosys\n  Enotblk\n  Enotdir\n  Enotsup\n  Enxio\n  Eopnotsupp\n  Eoverflow\n  Eperm\n  Epipe\n  Erange\n  Erofs\n  Espipe\n  Esrch\n  Estale\n  Etxtbsy\n  Exdev\n  Eof\n  InvalidTextData\n  NoTranslation(from: TextEncoding, to: TextEncoding)\n}\n The reasons why a file stream operation can fail. Most of these map to\n underlying POSIX errors.\n\nEacces\n Permission denied.\n\nEagain\n Resource temporarily unavailable.\n\nEbadf\n Bad file number\n\nEbadmsg\n Bad message.\n\nEbusy\n File busy.\n\nEdeadlk\n Resource deadlock avoided.\n\nEdeadlock\n On most architectures, same as `Edeadlk`. On some architectures, it\n\n means &quot;File locking deadlock error.&quot;\n\nEdquot\n Disk quota exceeded.\n\nEexist\n File already exists.\n\nEfault\n Bad address in system call argument.\n\nEfbig\n File too large.\n\nEftype\n Inappropriate file type or format. Usually caused by trying to set the\n\n &quot;sticky bit&quot; on a regular file (not a directory).\n\nEintr\n Interrupted system call.\n\nEinval\n Invalid argument.\n\nEio\n I/O error.\n\nEisdir\n Illegal operation on a directory.\n\nEloop\n Too many levels of symbolic links.\n\nEmfile\n Too many open files.\n\nEmlink\n Too many links.\n\nEmultihop\n Multihop attempted.\n\nEnametoolong\n Filename too long\n\nEnfile\n File table overflow\n\nEnobufs\n No buffer space available.\n\nEnodev\n No such device.\n\nEnolck\n No locks available.\n\nEnolink\n Link has been severed.\n\nEnoent\n No such file or directory.\n\nEnomem\n Not enough memory.\n\nEnospc\n No space left on device.\n\nEnosr\n No STREAM resources.\n\nEnostr\n Not a STREAM.\n\nEnosys\n Function not implemented.\n\nEnotblk\n Block device required.\n\nEnotdir\n Not a directory.\n\nEnotsup\n Operation not supported.\n\nEnxio\n No such device or address.\n\nEopnotsupp\n Operation not supported on socket.\n\nEoverflow\n Value too large to be stored in data type.\n\nEperm\n Not owner.\n\nEpipe\n Broken pipe.\n\nErange\n Result too large.\n\nErofs\n Read-only file system.\n\nEspipe\n Invalid seek.\n\nEsrch\n No such process.\n\nEstale\n Stale remote file handle.\n\nEtxtbsy\n Text file busy.\n\nExdev\n Cross-domain link.\n\nEof\n The end of the file stream was reached before the requested data could\n be read.\n\nInvalidTextData\n Invalid data was encountered when reading text.\n\nNoTranslation(from: TextEncoding, to: TextEncoding)\n Text data was encountered that can&#39;t be converted from/to the relevant\n text encoding.\n\nSynonyms:\nfile_streams/file_stream_error.FileStreamError\nfile_streams/file_stream_error FileStreamError","url":"file_streams/file_stream_error.html#FileStreamError"},{"doc":"file_streams/file_stream_error","title":"file_streams/file_stream_error","content":"","url":"file_streams/file_stream_error.html"},{"doc":"file_streams/file_stream","title":"FileStream","content":"pub opaque type FileStream\n A file stream that data can be read from and/or written to depending on the\n mode specified when it was opened.\n\n\nSynonyms:\nfile_streams/file_stream.FileStream\nfile_streams/file_stream FileStream","url":"file_streams/file_stream.html#FileStream"},{"doc":"file_streams/file_stream","title":"FileStreamLocation","content":"pub type FileStreamLocation {\n  BeginningOfFile(offset: Int)\n  CurrentLocation(offset: Int)\n  EndOfFile(offset: Int)\n}\n A file stream location defined relative to the beginning of the file,\n the end of the file, or the current position in the file stream. This is\n used with the [`position()`](#position) function.\n\nBeginningOfFile(offset: Int)\n A location relative to the beginning of the file, i.e. an absolute offset\n in the file stream. The offset should not be negative.\n\nCurrentLocation(offset: Int)\n A location relative to the current position in the file stream. The offset\n can be either positive or negative.\n\nEndOfFile(offset: Int)\n A location relative to the end of the file stream. The offset should not\n be positive.\n\nSynonyms:\nfile_streams/file_stream.FileStreamLocation\nfile_streams/file_stream FileStreamLocation","url":"file_streams/file_stream.html#FileStreamLocation"},{"doc":"file_streams/file_stream","title":"close","content":"pub fn close(stream: FileStream) -&gt; Result(Nil, FileStreamError)\n Closes a file stream that was opened with [`open()`](#open).\n\nSynonyms:\nfile_streams/file_stream.close\nfile_streams/file_stream close","url":"file_streams/file_stream.html#close"},{"doc":"file_streams/file_stream","title":"open","content":"pub fn open(\n  filename: String,\n  mode: List(FileOpenMode),\n) -&gt; Result(FileStream, FileStreamError)\n Opens a new file stream that can read and/or write data from the specified\n file. See [`FileOpenMode`](./file_open_mode.html#FileOpenMode) for all of\n the available file modes.\n\n For simple cases of opening a file stream use one of the\n [`open_read()`](#open_read), [`open_read_text()`](#open_read_text),\n [`open_write()`](#open_write), or [`open_write_text()`](#open_write_text)\n helper functions.\n \n Once the file stream is no longer needed it should be closed with\n [`close()`](#close).\n\nSynonyms:\nfile_streams/file_stream.open\nfile_streams/file_stream open","url":"file_streams/file_stream.html#open"},{"doc":"file_streams/file_stream","title":"open_read","content":"pub fn open_read(\n  filename: String,\n) -&gt; Result(FileStream, FileStreamError)\n Opens a new file stream for reading binary data from the specified file.\n\nSynonyms:\nfile_streams/file_stream.open_read\nfile_streams/file_stream open_read","url":"file_streams/file_stream.html#open_read"},{"doc":"file_streams/file_stream","title":"open_read_text","content":"pub fn open_read_text(\n  filename: String,\n) -&gt; Result(FileStream, FileStreamError)\n Opens a new file stream for reading UTF-8 text from a file.\n\nSynonyms:\nfile_streams/file_stream.open_read_text\nfile_streams/file_stream open_read_text","url":"file_streams/file_stream.html#open_read_text"},{"doc":"file_streams/file_stream","title":"open_write","content":"pub fn open_write(\n  filename: String,\n) -&gt; Result(FileStream, FileStreamError)\n Opens a new file stream for writing binary data to the specified file.\n\nSynonyms:\nfile_streams/file_stream.open_write\nfile_streams/file_stream open_write","url":"file_streams/file_stream.html#open_write"},{"doc":"file_streams/file_stream","title":"open_write_text","content":"pub fn open_write_text(\n  filename: String,\n) -&gt; Result(FileStream, FileStreamError)\n Opens a new file stream for writing UTF-8 text to a file.\n\nSynonyms:\nfile_streams/file_stream.open_write_text\nfile_streams/file_stream open_write_text","url":"file_streams/file_stream.html#open_write_text"},{"doc":"file_streams/file_stream","title":"position","content":"pub fn position(\n  stream: FileStream,\n  location: FileStreamLocation,\n) -&gt; Result(Int, FileStreamError)\n Sets the position of a file stream to the given location, where the location\n can be relative to the beginning of the file, the end of the file, or the\n current position in the file. On success, returns the current position in\n the file stream as an absolute offset in bytes.\n\nSynonyms:\nfile_streams/file_stream.position\nfile_streams/file_stream position","url":"file_streams/file_stream.html#position"},{"doc":"file_streams/file_stream","title":"read_bytes","content":"pub fn read_bytes(\n  stream: FileStream,\n  byte_count: Int,\n) -&gt; Result(BitArray, FileStreamError)\n Reads bytes from a binary file stream. The returned number of bytes may be\n fewer than the number that was requested if the end of the file stream was\n reached.\n\n If the end of the file stream is encountered before any bytes can be read\n then `Error(Eof)` is returned.\n\nSynonyms:\nfile_streams/file_stream.read_bytes\nfile_streams/file_stream read_bytes","url":"file_streams/file_stream.html#read_bytes"},{"doc":"file_streams/file_stream","title":"read_bytes_exact","content":"pub fn read_bytes_exact(\n  stream: FileStream,\n  byte_count: Int,\n) -&gt; Result(BitArray, FileStreamError)\n Reads the requested number of bytes from a binary file stream. If the\n requested number of bytes can&#39;t be read prior to reaching the end of the\n file stream then `Error(Eof)` is returned.\n\nSynonyms:\nfile_streams/file_stream.read_bytes_exact\nfile_streams/file_stream read_bytes_exact","url":"file_streams/file_stream.html#read_bytes_exact"},{"doc":"file_streams/file_stream","title":"read_chars","content":"pub fn read_chars(\n  stream: FileStream,\n  count: Int,\n) -&gt; Result(String, FileStreamError)\n Reads the next `count` characters from a text file stream. The returned\n number of characters may be fewer than the number that was requested if the\n end of the stream is reached.\n\nSynonyms:\nfile_streams/file_stream.read_chars\nfile_streams/file_stream read_chars","url":"file_streams/file_stream.html#read_chars"},{"doc":"file_streams/file_stream","title":"read_float32_be","content":"pub fn read_float32_be(\n  stream: FileStream,\n) -&gt; Result(Float, FileStreamError)\n Reads a big-endian 32-bit float from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_float32_be\nfile_streams/file_stream read_float32_be","url":"file_streams/file_stream.html#read_float32_be"},{"doc":"file_streams/file_stream","title":"read_float32_le","content":"pub fn read_float32_le(\n  stream: FileStream,\n) -&gt; Result(Float, FileStreamError)\n Reads a little-endian 32-bit float from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_float32_le\nfile_streams/file_stream read_float32_le","url":"file_streams/file_stream.html#read_float32_le"},{"doc":"file_streams/file_stream","title":"read_float64_be","content":"pub fn read_float64_be(\n  stream: FileStream,\n) -&gt; Result(Float, FileStreamError)\n Reads a big-endian 64-bit float from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_float64_be\nfile_streams/file_stream read_float64_be","url":"file_streams/file_stream.html#read_float64_be"},{"doc":"file_streams/file_stream","title":"read_float64_le","content":"pub fn read_float64_le(\n  stream: FileStream,\n) -&gt; Result(Float, FileStreamError)\n Reads a little-endian 64-bit float from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_float64_le\nfile_streams/file_stream read_float64_le","url":"file_streams/file_stream.html#read_float64_le"},{"doc":"file_streams/file_stream","title":"read_int16_be","content":"pub fn read_int16_be(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a big-endian 16-bit signed integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_int16_be\nfile_streams/file_stream read_int16_be","url":"file_streams/file_stream.html#read_int16_be"},{"doc":"file_streams/file_stream","title":"read_int16_le","content":"pub fn read_int16_le(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a little-endian 16-bit signed integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_int16_le\nfile_streams/file_stream read_int16_le","url":"file_streams/file_stream.html#read_int16_le"},{"doc":"file_streams/file_stream","title":"read_int32_be","content":"pub fn read_int32_be(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a big-endian 32-bit signed integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_int32_be\nfile_streams/file_stream read_int32_be","url":"file_streams/file_stream.html#read_int32_be"},{"doc":"file_streams/file_stream","title":"read_int32_le","content":"pub fn read_int32_le(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a little-endian 32-bit signed integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_int32_le\nfile_streams/file_stream read_int32_le","url":"file_streams/file_stream.html#read_int32_le"},{"doc":"file_streams/file_stream","title":"read_int64_be","content":"pub fn read_int64_be(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a big-endian 64-bit signed integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_int64_be\nfile_streams/file_stream read_int64_be","url":"file_streams/file_stream.html#read_int64_be"},{"doc":"file_streams/file_stream","title":"read_int64_le","content":"pub fn read_int64_le(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a little-endian 64-bit signed integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_int64_le\nfile_streams/file_stream read_int64_le","url":"file_streams/file_stream.html#read_int64_le"},{"doc":"file_streams/file_stream","title":"read_int8","content":"pub fn read_int8(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads an 8-bit signed integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_int8\nfile_streams/file_stream read_int8","url":"file_streams/file_stream.html#read_int8"},{"doc":"file_streams/file_stream","title":"read_line","content":"pub fn read_line(\n  stream: FileStream,\n) -&gt; Result(String, FileStreamError)\n Reads the next line of text from a text file stream. The returned string\n will include the newline `\\n` character. If the stream contains a Windows\n newline `\\r\\n` then only the `\\n` will be returned.\n\nSynonyms:\nfile_streams/file_stream.read_line\nfile_streams/file_stream read_line","url":"file_streams/file_stream.html#read_line"},{"doc":"file_streams/file_stream","title":"read_list","content":"pub fn read_list(\n  stream: FileStream,\n  item_read_fn: fn(FileStream) -&gt; Result(a, FileStreamError),\n  item_count: Int,\n) -&gt; Result(List(a), FileStreamError)\n Reads the specified type the requested number of times from a binary file\n stream, e.g. two little-endian 32-bit integers, or four big-endian 64-bit\n floats, and returns the values in a list.\n\n ## Examples\n\n \n read_list(stream, read_stream.read_int32_le, 2)\n |&gt; Ok([1, 2])\n\n read_list(stream, read_stream.read_float64_be, 4)\n |&gt; Ok([1.0, 2.0])\n \n\nSynonyms:\nfile_streams/file_stream.read_list\nfile_streams/file_stream read_list","url":"file_streams/file_stream.html#read_list"},{"doc":"file_streams/file_stream","title":"read_remaining_bytes","content":"pub fn read_remaining_bytes(\n  stream: FileStream,\n) -&gt; Result(BitArray, FileStreamError)\n Reads all remaining bytes from a binary file stream.\n\n If no more data is available in the file stream then this function will\n return an empty bit array. It never returns `Error(Eof)`.\n\nSynonyms:\nfile_streams/file_stream.read_remaining_bytes\nfile_streams/file_stream read_remaining_bytes","url":"file_streams/file_stream.html#read_remaining_bytes"},{"doc":"file_streams/file_stream","title":"read_uint16_be","content":"pub fn read_uint16_be(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a big-endian 16-bit unsigned integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_uint16_be\nfile_streams/file_stream read_uint16_be","url":"file_streams/file_stream.html#read_uint16_be"},{"doc":"file_streams/file_stream","title":"read_uint16_le","content":"pub fn read_uint16_le(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a little-endian 16-bit unsigned integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_uint16_le\nfile_streams/file_stream read_uint16_le","url":"file_streams/file_stream.html#read_uint16_le"},{"doc":"file_streams/file_stream","title":"read_uint32_be","content":"pub fn read_uint32_be(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a big-endian 32-bit unsigned integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_uint32_be\nfile_streams/file_stream read_uint32_be","url":"file_streams/file_stream.html#read_uint32_be"},{"doc":"file_streams/file_stream","title":"read_uint32_le","content":"pub fn read_uint32_le(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a little-endian 32-bit unsigned integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_uint32_le\nfile_streams/file_stream read_uint32_le","url":"file_streams/file_stream.html#read_uint32_le"},{"doc":"file_streams/file_stream","title":"read_uint64_be","content":"pub fn read_uint64_be(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a big-endian 64-bit unsigned integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_uint64_be\nfile_streams/file_stream read_uint64_be","url":"file_streams/file_stream.html#read_uint64_be"},{"doc":"file_streams/file_stream","title":"read_uint64_le","content":"pub fn read_uint64_le(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads a little-endian 64-bit unsigned integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_uint64_le\nfile_streams/file_stream read_uint64_le","url":"file_streams/file_stream.html#read_uint64_le"},{"doc":"file_streams/file_stream","title":"read_uint8","content":"pub fn read_uint8(\n  stream: FileStream,\n) -&gt; Result(Int, FileStreamError)\n Reads an 8-bit unsigned integer from a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.read_uint8\nfile_streams/file_stream read_uint8","url":"file_streams/file_stream.html#read_uint8"},{"doc":"file_streams/file_stream","title":"sync","content":"pub fn sync(stream: FileStream) -&gt; Result(Nil, FileStreamError)\n Syncs a file stream that was opened for writing. This ensures that any write\n buffers kept by the operating system (not by the Erlang runtime system) are\n written to disk.\n\n When a file stream is opened with delayed writes enabled to improve\n performance, syncing can return an error related to flushing recently\n written data to the underlying device.\n\nSynonyms:\nfile_streams/file_stream.sync\nfile_streams/file_stream sync","url":"file_streams/file_stream.html#sync"},{"doc":"file_streams/file_stream","title":"write_bytes","content":"pub fn write_bytes(\n  stream: FileStream,\n  bytes: BitArray,\n) -&gt; Result(Nil, FileStreamError)\n Writes bytes to a binary file stream.\n\nSynonyms:\nfile_streams/file_stream.write_bytes\nfile_streams/file_stream write_bytes","url":"file_streams/file_stream.html#write_bytes"},{"doc":"file_streams/file_stream","title":"write_chars","content":"pub fn write_chars(\n  stream: FileStream,\n  chars: String,\n) -&gt; Result(Nil, FileStreamError)\n Writes characters to a text file stream. This will convert the characters to\n the text encoding in use for the file stream.\n\nSynonyms:\nfile_streams/file_stream.write_chars\nfile_streams/file_stream write_chars","url":"file_streams/file_stream.html#write_chars"},{"doc":"file_streams/file_stream","title":"file_streams/file_stream","content":" Use Erlang file streams in Gleam.","url":"file_streams/file_stream.html"}]);